@font-face {
  font-family: 'ruxicomoon';
  src:url('fonts/icomoon.eot');
  src:url('fonts/icomoon.eot?#iefix') format('embedded-opentype'),
    url('fonts/icomoon.ttf') format('truetype'),
    url('fonts/icomoon.woff') format('woff'),
    url('fonts/icomoon.svg#icomoon') format('svg');
  font-weight: normal;
  font-style: normal;
}

[class^="icon-"], [class*=" icon-"] {
  font-family: 'ruxicomoon';
  speak: none;
  font-style: normal;
  font-weight: normal;
  font-variant: normal;
  text-transform: none;
  line-height: 1;

  /* Better Font Rendering =========== */
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}

.icon-home:before {
  content: "\e600";
}
.icon-eye:before {
  content: "\e601";
}
.icon-disk:before {
  content: "\e602";
}
.icon-cog:before {
  content: "\e603";
}
.icon-blog:before {
  content: "\e604";
}
.icon-switch:before {
  content: "\e605";
}
.icon-pencil:before {
  content: "\e606";
}
.icon-remove:before {
  content: "\e607";
}
.icon-cancel-circle:before {
  content: "\e608";
}
.icon-happy:before {
  content: "\e609";
}
.icon-arrow-right:before {
  content: "\e60c";
}
.icon-arrow-left:before {
  content: "\e60d";
}
