<!DOCTYPE HTML>
<html>
  <head>
    <meta http-equiv="content-type" content="text/html; charset=utf-8" />
    <!-- no cache -->
    <meta http-equiv="cache-control" content="max-age=0" />
    <meta http-equiv="cache-control" content="no-cache" />
    <meta http-equiv="expires" content="0" />
    <meta http-equiv="expires" content="Tue, 01 Jan 1980 1:00:00 GMT" />
    <meta http-equiv="pragma" content="no-cache" />
    <!-- no cache -->
    <meta name="description" content="{%block meta_description%}{{blog.description}}{%endblock%}" />
    <title>{%block title%}{{blog.name}}{%endblock%}</title>
    <link rel="stylesheet" href="/{{blog.theme}}/static/css/layout.css?v201402181631" type="text/css" />
    <link rel="stylesheet" href="/{{blog.theme}}/static/css/{%block css_this_page%}{%endblock%}?v201402181631" type="text/css" />
    <link rel="shortcut icon" href="/{{blog.theme}}/static/images/favicon.ico">
    {% block header_extra %}
    {% endblock %}
  </head>
  <body>
    <div class="header">
      <div class="header-box">
        <h1><a href="/" title="{{blog.name}}">{{blog.name}}</a></h1>
        <h2>{{blog.description}}</h2>
      </div>
    </div>
    <div class="container">
      <div class="cut">* * *</div>
      <div class="content">
        {%block content%}
        {%endblock%}
      </div>
      <div class="aboutme">
        <img src="/{{blog.theme}}/static/images/spinner-circle-fade.gif" class="loader"/>
        {% if author.url %}
        <a href="{{author.url}}" title="{{author.name}}">
          {% endif %}
          <img src="https://secure.gravatar.com/avatar/{{author.gravatar_id}}?s=80" class="avatar" />
          {% if author.url %}
        </a>
        {% endif %}
        {% if author.url %}
        <a href="{{author.url}}" title="{{author.name}}">
          {% endif %}
          <strong>{{author.name}}</strong>
          {% if author.url %}
        </a>
        {% endif %}
        <p>{{author.description}}</p>
      </div>
      <div class="footer-push"></div>
    </div>
    <div class="cut">* * *</div>
    <div class="footer">
      © 2013 ,
      <a href="mailto:{{author.email}}">{{author.name}}</a> |
      site built by <a href="https://github.com/hit9/rux.git">hit9/rux.git</a>
    </div>
  </body>
</html>
<script>
  var c = new XMLHttpRequest();
  c.open('GET', '/{{blog.theme}}/static/art.txt');
  c.onreadystatechange = function() {
    console.log(c.responseText);
    console.log('为记录我与铷铷的爱情而生的博客系统!');
    console.log('                -- Chao Wang (hit9)');
  }
  c.send();
</script>
