.item+.item{border-top:1px solid #dedddf;margin-top:25px;padding-top:25px}.item-p+.item{margin-top:40px;padding-top:30px}.item-no-p+.item-p{padding-top:45px}.item-p+.item-p{border:0}.post{position:relative}.post h1.title{font:32px "OFL Sorts Mill Goudy","OFL Sorts Mill Goudy TT",serif;font-weight:200;font-weight:400;line-height:1.4;text-align:right}.post h1.title a.title{float:left;text-align:left}.post h1.title a.date{font-size:18px;font-style:italic}.post-without-title-pic .read-more{letter-spacing:3px;text-align:right;font-style:italic}.post-without-title-pic .summary{z-index:-1}.post-without-title-pic h1.title{margin-bottom:22px}.post-without-title-pic h1.title a.date{color:#292928;text-decoration:none}.post-with-title-pic{padding:270px 22px 22px;cursor:pointer;background-image:-webkit-gradient(linear, 0 0, 0 100%, from(rgba(0,0,0,0.01) 40%), to(rgba(0,0,0,0.7) 80%));background-image:-webkit-linear-gradient(top, rgba(0,0,0,0.01) 40%, rgba(0,0,0,0.7) 80%);background-image:-moz-linear-gradient(top, rgba(0,0,0,0.01) 40%, rgba(0,0,0,0.7) 80%);background-image:linear-gradient(top, rgba(0,0,0,0.01) 40%, rgba(0,0,0,0.7) 80%);background-repeat:repeat-x;-webkit-transition:all 0.1s ease-in-out;-moz-transition:all 0.1s ease-in-out;-o-transition:all 0.1s ease-in-out;transition:all 0.1s ease-in-out}.post-with-title-pic h1.title{color:#fff;-webkit-transition:all 0.5s ease-in-out;-moz-transition:all 0.5s ease-in-out;-o-transition:all 0.5s ease-in-out;transition:all 0.5s ease-in-out}.post-with-title-pic h1.title a{color:#fff}.post-with-title-pic h1.title a:hover{color:#fff}.post-with-title-pic .title-pic-preview{max-width:100%;position:absolute;top:0;left:0;z-index:-1;width:100%;height:100%;background-repeat:no-repeat;background-position:center;background-size:cover}.post-with-title-pic a.entry-link{position:absolute;top:0;left:0;width:100%;height:100%}.post-with-title-pic:hover{background-image:-webkit-gradient(linear, 0 0, 0 100%, from(rgba(0,0,0,0.01) 40%), to(rgba(0,0,0,0.55) 80%));background-image:-webkit-linear-gradient(top, rgba(0,0,0,0.01) 40%, rgba(0,0,0,0.55) 80%);background-image:-moz-linear-gradient(top, rgba(0,0,0,0.01) 40%, rgba(0,0,0,0.55) 80%);background-image:linear-gradient(top, rgba(0,0,0,0.01) 40%, rgba(0,0,0,0.55) 80%)}.post-with-title-pic>.spinner{background-repeat:no-repeat;position:absolute;top:143px;left:275px;z-index:-3}.post-with-title-pic .spinner{-webkit-animation:spriteSpin 0.2s steps(12) infinite;animation:spriteSpin 0.2s steps(12) infinite;display:block;margin:0 auto;width:50px;height:50px}.paging{-webkit-transition:all 0.5s ease-in-out;-moz-transition:all 0.5s ease-in-out;-o-transition:all 0.5s ease-in-out;transition:all 0.5s ease-in-out;width:100%;margin:15px 0;line-height:1;font-size:42px;font-weight:100;display:inline-block}.paging a{display:block;width:50%}.paging a.prev{float:left;text-align:left}.paging a.next{float:right;text-align:right}.aboutme{border-top:2px solid #dedddf}
