.content h1.title{font:27px "OFL Sorts Mill Goudy","OFL Sorts Mill Goudy TT",serif;font-weight:200;text-align:center;display:block;margin:50px 0 30px}.content p.date{font:18px "OFL Sorts Mill Goudy","OFL Sorts Mill Goudy TT",serif;font-weight:200;font-style:italic;text-align:right;margin:5px 0 30px 0}.content div.title-pic-container,.content img.title-pic{width:600px;text-align:center}.content div.title-pic-container{position:relative}.content div.title-pic-container .loader{position:absolute;top:0;left:275px;height:50px;width:50px;z-index:-3}.content div.posts-nav{width:100%;-webkit-transition:all 0.5s ease-in-out;-moz-transition:all 0.5s ease-in-out;-o-transition:all 0.5s ease-in-out;transition:all 0.5s ease-in-out;display:inline-block;border-top:1px solid #dedddf;border-bottom:1px solid #dedddf;margin:21px 0}.content div.posts-nav a.next,.content div.posts-nav a.prev{padding:30px 0;background-color:inherit;color:#292928;font-size:20px;display:block;width:50%}.content div.posts-nav a.prev{float:left;text-align:left}.content div.posts-nav a.prev [class^="icon-"]:before,.content div.posts-nav a.prev [class*=" icon-"]:before{margin-right:10px}.content div.posts-nav a.next{float:right;text-align:right}.content div.posts-nav a.next [class^="icon-"]:before,.content div.posts-nav a.next [class*=" icon-"]:before{margin-left:10px}.content div.posts-nav a:hover{text-decoration:none}.content div.posts-nav a.next:hover,.content div.posts-nav a.prev:hover{background-color:rgba(0,0,0,0.025)}#disqus_thread{border-bottom:1px solid #dedddf;padding:21px 0}
