@charset "utf-8"

$red: #CC0033
$gray: #777
$black: #292928

$width: 600px

=border-radius($r: 4px)
  -webkit-border-radius: $r
  -moz-border-radius: $r
  -ms-border-radius: $r
  -o-border-radius: $r
  border-radius: $r

=ofl-font($font-size: 17px)
  font: $font-size 'OFL Sorts Mill Goudy', 'OFL Sorts Mill Goudy TT', serif
  font-weight: 200

=bigtitle
  +ofl-font(27px)
  text-align: center

=transition($x)
  -webkit-transition: all $x ease-in-out
  -moz-transition: all $x ease-in-out
  -o-transition: all $x ease-in-out
  transition: all $x ease-in-out
