# coding=utf8

#     _/_/_/
#    _/    _/  _/    _/  _/    _/
#   _/_/_/    _/    _/    _/_/
#  _/    _/  _/    _/  _/    _/
# _/    _/    _/_/_/  _/    _/
#

"""
    Rux
    ~~~

    Micro & Fast static blog generator (markdown => html).

    :author: Chao Wang (Hit9)
    :license: BSD
"""

__version__ = '0.6.1'

charset = 'utf8'  # utf8 input & output
src_ext = '.md'
out_ext = '.html'
src_dir = 'src'
out_dir = '.'
