@import base
@import normalize
@import markdown

/* sticky footer */

*
  margin: 0

html, body
  height: 100%

.container
  min-height: 100%
  height: auto !important
  margin: 0 auto -142px

.footer, .footer-push
  height: 142px

/* sticky footer end */


/* fonts */
// @import url(http://fonts.googleapis.com/css?family=Merriweather:400,300)
@import url(http://fonts.googleapis.com/css?family=Source+Sans+Pro)
@import url(http://fonts.googleapis.com/css?family=OFL+Sorts+Mill+Goudy+TT:regular,italic)

body
  font: 16px/1.7 "Source Sans Pro", "Helvetica Neue", Helvetica, Arial, Sans-serif
  background: #fff
  color: $black
  font-weight: 400

a
  text-decoration: none

a:link
  color: $red
  text-decoration: none

a:hover
  color: $red
  text-decoration: underline

a:visited
  color: $red

.container
  width: $width

.header-box, .content, .footer
  width: $width
  margin: 0 auto
  text-align: center

.content
  text-align: left

.header
  position: relative
  border-bottom: 2px solid #dedddf
  z-index: 10
  width: 100%
  padding: 60px 0 20px 0
  box-shadow: 0 1px 2px rgba(0,0,0,.04),inset 0 1px 0 #fff
  background-color: #fafbfc
  background-image: -webkit-gradient(linear,0 0,0 100%,from(#fcfdfe),to(#f8f9fa))
  background-image: -webkit-linear-gradient(top,#fcfdfe,#f8f9fa)
  background-image: linear-gradient(top,#fcfdfe,#f8f9fa)
  background-repeat: repeat-x

  h1
    a
      +ofl-font(43px)
      font-weight: 200
    margin: 0 0 15px 0
  h2
    +ofl-font(20px)
    font-style: italic
    color: #777

.footer
  width: $width
  margin: 0 auto
  font-size: 15px
  color: #999
  font-weight: 200
  padding-top: 50px
  a
    color: #999
    text-decoration: underline

.cut
  clear: both
  color: #aaa
  text-align: center
  letter-spacing: 3px
  margin: 15px 0
  font-size: 30px
  opacity: .6

.aboutme
  clear: both
  position: relative
  padding: 20px 0
  // border-top: 2px solid #dedddf
  color: #42474a
  img.avatar
    +border-radius(50em)
    width: 80px
    height: 80px
    float: left
    margin-right: 20px
    z-index: -1
  .loader
    position: absolute
    top: 45px
    left: 25px
    height: 50px
    width: 50px
    z-index: -3

@import "iconmoon.css"
