@import base

.content
  h1.title
    +bigtitle
    display: block
    margin: 50px 0 30px
  p.date 
    +ofl-font(18px)
    font-style: italic
    text-align: right
    margin: 5px 0 30px 0
  div.title-pic-container, img.title-pic
    width: $width
    text-align: center
  div.title-pic-container
    position: relative
  div.title-pic-container .loader
    position: absolute
    top: 0
    left: 275px
    height: 50px
    width: 50px
    z-index: -3

  div.posts-nav
    width: 100%
    +transition(.5s)
    display: inline-block
    border-top: 1px solid #dedddf
    border-bottom: 1px solid #dedddf
    margin: 21px 0

    a.next, a.prev
      padding: 30px 0
      background-color: inherit
      color: $black
      font-size: 20px
      display: block
      width: 50%
    a.prev
      float: left
      text-align: left
      [class^="icon-"]:before, [class*=" icon-"]:before
        margin-right: 10px
    a.next
      float: right
      text-align: right
      [class^="icon-"]:before, [class*=" icon-"]:before
        margin-left: 10px
    a:hover
      text-decoration: none
    a.next:hover, a.prev:hover
      background-color: rgba(0,0,0,.025)


#disqus_thread
  border-bottom: 1px solid #dedddf
  padding: 21px 0
